#!/usr/bin/python
# -*- coding: utf-8 -*-

# Library für den Sensor
from Adafruit_BMP085 import BMP085

import rrdtool
import sys
import time


# Festlegung globaler Variablen
dbname = 'bmp085'                                               # Name fuer Grafiken etc
filename = dbname +'.rrd'                                       # Dateinamen mit Datum
steps = 10                                                      # Zeitintervall fuer die Messung in Sekunden
path = '/var/www/plots/'                                        # absoluter Pfad zum Ablegen der Plots
i = 0                                                           # Schleifenbedingung für den Hauptteil


# RRD-Datenbank anlegen, wenn nicht vorhanden
try:
    with open(filename): pass
    print "Datenbankdatei gefunden: " + filename
    i=1
except IOError:
    print "Ich erzeuge eine neue Datenbank: " + filename
    ret = rrdtool.create("%s" %(filename),
                         "--step","%s" %(steps),
                         "--start",'0',
                         "DS:bmp085_temp:GAUGE:2000:U:U",
                         "DS:bmp085_pres:GAUGE:2000:U:U",
                         "DS:bmp085_alti:GAUGE:2000:U:U",
                         "RRA:AVERAGE:0.5:1:2160",
                         "RRA:AVERAGE:0.5:5:2016",
                         "RRA:AVERAGE:0.5:15:2880",
                         "RRA:AVERAGE:0.5:60:8760",)
    i=1                          

# Sensor initialisieren
bmp = BMP085(0x77, 3, debug=False)

# Bildschirmausgabe
def ausgabe(d,u,t,p,a):
    sys.stdout.write(str('Datum: ') + d + '\n')
    sys.stdout.write(str('Uhrzeit: ') + u + '\n')
    sys.stdout.write(str('Temperatur:' ) + str(t) + '\n')
    sys.stdout.write(str('Luftdruck: ') + str(p) + '\n')
    sys.stdout.write(str('Höhenlage: ') + str(a) + '\n')
    

def plotten(a):

# Funktion zum Plotten der Grafiken
# a:   Wert, der geplottet werden soll
    
    # Beschriftung für die Grafiken festlegen
    if a == 'temp':
            title = 'Temperatur'
            label = 'in °C'
    elif a == 'pres':
            title = 'Luftdruck'
            label = 'in hPa'
    elif a == "alti":
            title = 'Hoehe'
            label = 'm über 0'
                                              
                                                    
    # Aufteilung in drei Plots
    for plot in ['daily' , 'weekly', 'monthly']:
                                          
        if plot == 'weekly':
                 period = 'w'
        elif plot == 'daily':
                 period = 'd'
        elif plot == 'monthly':
                 period = 'm'
                                                                                                                                 
                                                                                         
        # Grafiken erzeugen                                                                                                                            
        ret = rrdtool.graph("%s%s_%s-%s.png" %(path,dbname,a,plot),
                             "--start",
                             "-1%s" %(period),
                             "--title=%s (%s)" %(title,plot),
                             "--vertical-label=%s" %(label),
                             '--watermark=leben-zwo-punkt-null.de',
                             "-w 800",
                             "--alt-autoscale",
                             "--slope-mode",
                             "DEF:%s=%s:%s_%s:AVERAGE" %(a, filename, dbname, a),
                             "LINE1:%s#0000FF:%s_%s" %(a, dbname, a))

while i!=0:
    datum = time.strftime('%d %m %Y')
    uhrzeit = time.strftime('%H:%M:%S')
    
    # Messung von Temperatur, Druck, Luftfeuchte
    bmp085_temp=bmp.readTemperature()
    bmp085_pres=(bmp.readPressure() / 100.0)
    bmp085_alti=bmp.readAltitude()
     
    # Messwerte in die RRD-Datei schreiben
    from rrdtool import update as rrd_update
    ret = rrd_update('%s' %(filename), 'N:%s:%s:%s' %(bmp085_temp, bmp085_pres, bmp085_alti));
    
    # Grafiken erzeugen
    print "Erzeuge Grafiken"
    plotten('temp')
    plotten('pres')
    
    # Bildschirmausgabe der Messwerte
    #ausgabe(datum,uhrzeit,bmp085_temp,bmp085_pres,bmp085_alti)
    
    # Warten, bis die neue Messung beginnt 
    print "Neue Messung startet in %s Sekunden" %(steps)
    time.sleep(steps)